# This scripts downloads, prepares and saves the `ss3_pbmc` data.

args <- R.utils::commandArgs(
  trailingOnly = TRUE,
  asValues = TRUE
)

suppressMessages({
  library(scRNAseq)
  library(scran)
  library(scater)
  library(AnnotationHub)
  library(AnnotationDbi)
  library(EnsDb.Hsapiens.v86)
})

set.seed("21122021")

ss3_pbmc <- readRDS(args$raw_data)

anno <- select(
  EnsDb.Hsapiens.v86,
  keys = rownames(ss3_pbmc),
  keytype = "GENEID",
  columns = c("SYMBOL", "SEQNAME")
)
rowData(ss3_pbmc) <- anno[match(rownames(ss3_pbmc), anno[, 1]), -1]

clusters <- quickCluster(ss3_pbmc)
ss3_pbmc <- computeSumFactors(ss3_pbmc, clusters = clusters)
ss3_pbmc <- logNormCounts(ss3_pbmc)

dec_ss3_pbmc <- modelGeneVarByPoisson(ss3_pbmc)
top_ss3_pbmc <- getTopHVGs(dec_ss3_pbmc, n = 2000)
ss3_pbmc <- ss3_pbmc[top_ss3_pbmc, ]

ss3_pbmc <- runPCA(ss3_pbmc)
ss3_pbmc <- runTSNE(ss3_pbmc, dimred = "PCA")
ss3_pbmc <- runUMAP(ss3_pbmc, dimred = "PCA")

gene_name <- rowData(ss3_pbmc)$SYMBOL
no_symbol_ind <- which(is.na(gene_name))
gene_name[no_symbol_ind] <- rownames(ss3_pbmc)[no_symbol_ind]
rownames(ss3_pbmc) <- gene_name

colLabels(ss3_pbmc) <- factor(ss3_pbmc$clusterName)

saveRDS(ss3_pbmc, args$data)
